/**********************************************************************
 
	Copyright (C) 2003 Hirohisa MORI <joshua@nichibun.ac.jp>
 
	This program is free software; you can redistribute it 
	and/or modify it under the terms of the GLOBALBASE 
	Library General Public License (G-LGPL) as published by 

	http://www.globalbase.org/
 
	This program is distributed in the hope that it will be 
	useful, but WITHOUT ANY WARRANTY; without even the 
	implied warranty of MERCHANTABILITY or FITNESS FOR A 
	PARTICULAR PURPOSE.

**********************************************************************/



#ifndef ___M_NETUTILS_H___
#define ___M_NETUTILS_H___

#include	<netdb.h>

struct hostent_ext {

#ifdef NON_UNIVERSAL
	char h_name[256];  /* official name of host */
	char *h_aliases[1];   /* alias list (always set to be 0) */
	int  h_addrtype;    /* host address type */
#define AF_INET 2
	int  h_length; /* length of address */
	char h_addr_list[1][4]; /* list of addresses from name server */
#endif

	struct hostent d;
	struct hostent *next;
};

#define   h_addr  h_addr_list[0]   /* address, for backward compatibility */

#if !__MACH__
#define htonl(a) (a);
#define ntohl(a) (a);
#endif

#endif
